/**
 * <h1>mexc-api-sdk</h1>
 * <p>
 * MEXC Official Market and trade api sdk, easy to connection and send request to MEXC open api !
 * <p>
 * <h2>Table of APIS</h2>
 * <p>
 * <ul>
 * <li><a href="#init">Init</a></li>
 * <li><a href="#market">Market</a>
 * <p>
 * <ul>
 * <li><a href="#ping">Ping</a></li>
 * <li><a href="#check-server-time">Check Server Time</a></li>
 * <li><a href="#exchange-information">Exchange Information</a></li>
 * <li><a href="#recent-trades-list">Recent Trades List</a></li>
 * <li><a href="#order-book">Order Book</a></li>
 * <li><a href="#old-trade-lookup">Old Trade Lookup</a></li>
 * <li><a href="#aggregate-trades-list">Aggregate Trades List</a></li>
 * <li><a href="#kline-data">kline Data</a></li>
 * <li><a href="#current-average-price">Current Average Price</a></li>
 * <li><a href="#24hr-ticker-price-change-statistics">24hr Ticker Price Change Statistics</a></li>
 * <li><a href="#symbol-price-ticker">Symbol Price Ticker</a></li>
 * <li><a href="#symbol-order-book-ticker">Symbol Order Book Ticker</a></li>
 * </ul></li>
 * <li><a href="#trade">Trade</a>
 * <p>
 * <ul>
 * <li><a href="#test-new-order">Test New Order</a></li>
 * <li><a href="#new-order">New Order</a></li>
 * <li><a href="#cancel-order">cancel-order</a></li>
 * <li><a href="#cancel-all-open-orders-on-a-symbol">Cancel all Open Orders on a Symbol</a></li>
 * <li><a href="#query-order">Query Order</a></li>
 * <li><a href="#current-open-orders">Current Open Orders</a></li>
 * <li><a href="#all-orders">All Orders</a></li>
 * <li><a href="#account-information">Account Information</a></li>
 * <li><a href="#account-trade-list">Account Trade List</a></li>
 * </ul></li>
 * </ul>
 * <p>
 * <h2>Init</h2>
 * <p>
 * <blockquote><pre>
 * //Javascript
 * import * as Mexc from 'mexc-sdk';
 * const apiKey = 'apiKey'
 * const apiSecret = 'apiSecret'
 * const client = new Mexc.Spot(apiKey, apiSecret);
 * </pre></blockquote>
 * <p>
 * <blockquote><pre>
 * // Go
 * package main
 * import (
 * 	"fmt"
 * 	"mexc-sdk/mexcsdk"
 * )
 * 
 * func main() {
 * 	apiKey := "apiKey"
 * 	apiSecret := "apiSecret"
 * 	spot := mexcsdk.NewSpot(apiKey, apiSecret)
 * }
 * </pre></blockquote>
 * <p>
 * <blockquote><pre>
 * # python
 * from mexc_sdk import Spot
 * spot = Spot(api_key='apiKey', apiSecret='apiSecret')
 * </pre></blockquote>
 * <p>
 * <blockquote><pre>
 * // java
 * import Mexc.Sdk.*;
 * class MyClass {
 *   public static void main(String[] args) {
 *     String apiKey= "apiKey";
 *     String apiSecret= "apiSecret";
 *     Spot mySpot = new Spot(apiKey, apiSecret);
 *   }
 * }
 * </pre></blockquote>
 * <p>
 * <blockquote><pre>
 * // dotnet
 * using System;
 * using System.Collections.Generic;
 * using Mxc.Sdk;
 * 
 * namespace dotnet
 * {
 *     class Program
 *     {
 *         static void Main(string[] args)
 *         {
 *             string  apiKey = "apiKey";
 *             string  apiSecret= "apiSecret";
 *             var spot = new Spot(apiKey, apiSecret);
 *         }
 *     }
 * }
 * 
 * </pre></blockquote>
 * <p>
 * <h2>Market</h2>
 * <p>
 * <h3>Ping</h3>
 * <p>
 * <blockquote><pre>
 * client.ping()
 * </pre></blockquote>
 * <p>
 * <h3>Check Server Time</h3>
 * <p>
 * <blockquote><pre>
 * client.time()
 * </pre></blockquote>
 * <p>
 * <h3>Exchange Information</h3>
 * <p>
 * <blockquote><pre>
 * client.exchangeInfo(options: any)
 * options:{symbol, symbols}
 * /**
 *  * choose one parameter
 *  *
 *  * symbol :
 *  *      example "BNBBTC";
 *  *
 *  * symbols :
 *  *      array of symbol
 *  *      example ["BTCUSDT","BNBBTC"];
 *  *
 *  *&#47;
 * </pre></blockquote>
 * <p>
 * <h3>Recent Trades List</h3>
 * <p>
 * <blockquote><pre>
 * client.trades(symbol: string, options: any = { limit: 500 })
 * options:{limit}
 * /**
 *  *
 *  * limit :
 *  *      Number of returned data
 *  *      Default 500;
 *  *      max 1000;
 *  *
 *  *&#47;
 * </pre></blockquote>
 * <p>
 * <h3>Order Book</h3>
 * <p>
 * <blockquote><pre>
 * client.depth(symbol: string, options: any = { limit: 100 })
 * options:{limit}
 * /**
 *  * limit :
 *  *      Number of returned data
 *  *      Default 100;
 *  *      max 5000;
 *  *      Valid:[5, 10, 20, 50, 100, 500, 1000, 5000]
 *  *
 *  *&#47;
 * </pre></blockquote>
 * <p>
 * <h3>Old Trade Lookup</h3>
 * <p>
 * <blockquote><pre>
 * client.historicalTrades(symbol: string, options: any = { limit: 500 })
 * options:{limit, fromId}
 * /**
 *  *
 *  * limit :
 *  *      Number of returned data
 *  *      Default 500;
 *  *      max 1000;
 *  *
 *  * fromId:
 *  *      Trade id to fetch from. Default gets most recent trades
 *  *
 *  *&#47;
 * 
 * </pre></blockquote>
 * <p>
 * <h3>Aggregate Trades List</h3>
 * <p>
 * <blockquote><pre>
 * client.aggTrades(symbol: string, options: any = { limit: 500 })
 * options:{fromId, startTime, endTime, limit}
 * /**
 *  *
 *  * fromId :
 *  *      id to get aggregate trades from INCLUSIVE
 *  *
 *  * startTime:
 *  *      start at
 *  *
 *  * endTime:
 *  *      end at
 *  *
 *  * limit :
 *  *      Number of returned data
 *  *      Default 500;
 *  *      max 1000;
 *  *
 *  *&#47;
 * </pre></blockquote>
 * <p>
 * <h3>kline Data</h3>
 * <p>
 * <blockquote><pre>
 * client.klines(symbol: string, interval: string, options: any = { limit: 500 })
 * options:{ startTime, endTime, limit}
 * /**
 *  *
 *  * interval :
 *  *      m :minute;
 *  *      h :Hour;
 *  *      d :day;
 *  *      w :week;
 *  *      M :month
 *  *      example : "1m"
 *  *
 *  * startTime :
 *  *      start at
 *  *
 *  * endTime :
 *  *      end at
 *  *
 *  * limit :
 *  *      Number of returned data
 *  *      Default 500;
 *  *      max 1000;
 *  *
 *  *&#47;
 * </pre></blockquote>
 * <p>
 * <h3>Current Average Price</h3>
 * <p>
 * <blockquote><pre>
 * client.avgPrice(symbol: string)
 * </pre></blockquote>
 * <p>
 * <h3>24hr Ticker Price Change Statistics</h3>
 * <p>
 * <blockquote><pre>
 * client.ticker24hr(symbol?: string)
 * </pre></blockquote>
 * <p>
 * <h3>Symbol Price Ticker</h3>
 * <p>
 * <blockquote><pre>
 * client.tickerPrice(symbol?: string)
 * </pre></blockquote>
 * <p>
 * <h3>Symbol Order Book Ticker</h3>
 * <p>
 * <blockquote><pre>
 * client.bookTicker(symbol?: string)
 * </pre></blockquote>
 * <p>
 * <h2>Trade</h2>
 * <p>
 * <h3>Test New Order</h3>
 * <p>
 * <blockquote><pre>
 * client.newOrderTest(symbol: string, side: string, orderType: string, options: any = {})
 * options:{ timeInForce, quantity, quoteOrderQty, price, newClientOrderId, stopPrice, icebergQty, newOrderRespType, recvWindow}
 * /**
 *  *
 *  * side:
 *  *      Order side
 *  *      ENUM:
 *  *        BUY
 *  *        SELL
 *  *
 *  * orderType:
 *  *      Order type
 *  *      ENUM:
 *  *        LIMIT
 *  *        MARKET
 *  *        STOP_LOSS
 *  *        STOP_LOSS_LIMIT
 *  *        TAKE_PROFIT
 *  *        TAKE_PROFIT_LIMIT
 *  *        LIMIT_MAKER
 *  *
 *  * timeInForce :
 *  *      How long an order will be active before expiration.
 *  *      GTC: Active unless the order is canceled
 *  *      IOC: Order will try to fill the order as much as it can before the order expires
 *  *      FOK: Active unless the full order cannot be filled upon execution.
 *  *
 *  * quantity :
 *  *      target quantity
 *  *
 *  * quoteOrderQty :
 *  *      Specify the total spent or received
 *  *
 *  * price :
 *  *      target price
 *  *
 *  * newClientOrderId :
 *  *      A unique id among open orders. Automatically generated if not sent
 *  *
 *  * stopPrice :
 *  *      sed with STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT, and TAKE_PROFIT_LIMIT orders
 *  *
 *  * icebergQty :
 *  *      Used with LIMIT, STOP_LOSS_LIMIT, and TAKE_PROFIT_LIMIT to create an iceberg order
 *  *
 *  * newOrderRespType :
 *  *      Set the response JSON. ACK, RESULT, or FULL;
 *  *      MARKET and LIMIT order types default to FULL, all other orders default to ACK
 *  *
 *  * recvWindow :
 *  *      Delay accept time
 *  *      The value cannot be greater than 60000
 *  *      defaults: 5000
 *  *
 *  *&#47;
 * 
 * </pre></blockquote>
 * <p>
 * <h3>New Order</h3>
 * <p>
 * <blockquote><pre>
 * client.newOrder(symbol: string, side: string, orderType: string, options: any = {})
 * options:{ timeInForce, quantity, quoteOrderQty, price, newClientOrderId, stopPrice, icebergQty, newOrderRespType, recvWindow}
 * /**
 *  *
 *  * side:
 *  *      Order side
 *  *      ENUM:
 *  *        BUY
 *  *        SELL
 *  *
 *  * orderType:
 *  *      Order type
 *  *      ENUM:
 *  *        LIMIT
 *  *        MARKET
 *  *        STOP_LOSS
 *  *        STOP_LOSS_LIMIT
 *  *        TAKE_PROFIT
 *  *        TAKE_PROFIT_LIMIT
 *  *        LIMIT_MAKER
 *  *
 *  * timeInForce :
 *  *      How long an order will be active before expiration.
 *  *      GTC: Active unless the order is canceled
 *  *      IOC: Order will try to fill the order as much as it can before the order expires
 *  *      FOK: Active unless the full order cannot be filled upon execution.
 *  *
 *  * quantity :
 *  *      target quantity
 *  *
 *  * quoteOrderQty :
 *  *      Specify the total spent or received
 *  *
 *  * price :
 *  *      target price
 *  *
 *  * newClientOrderId :
 *  *      A unique id among open orders. Automatically generated if not sent
 *  *
 *  * stopPrice :
 *  *      sed with STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT, and TAKE_PROFIT_LIMIT orders
 *  *
 *  * icebergQty :
 *  *      Used with LIMIT, STOP_LOSS_LIMIT, and TAKE_PROFIT_LIMIT to create an iceberg order
 *  *
 *  * newOrderRespType :
 *  *      Set the response JSON. ACK, RESULT, or FULL;
 *  *      MARKET and LIMIT order types default to FULL, all other orders default to ACK
 *  *
 *  * recvWindow :
 *  *      Delay accept time
 *  *      The value cannot be greater than 60000
 *  *      defaults: 5000
 *  *
 *  *&#47;
 * 
 * </pre></blockquote>
 * <p>
 * <h3>cancel-order</h3>
 * <p>
 * <blockquote><pre>
 * client.cancelOrder(symbol: string, options:any = {})
 * options:{ orderId, origClientOrderId, newClientOrderId}
 * /**
 *  *
 *  * Either orderId or origClientOrderId must be sent
 *  *
 *  * orderId:
 *  *      target orderId
 *  *
 *  * origClientOrderId:
 *  *      target origClientOrderId
 *  *
 *  * newClientOrderId:
 *  *      Used to uniquely identify this cancel. Automatically generated by default.
 *  *
 *  *&#47;
 * 
 * </pre></blockquote>
 * <p>
 * <h3>Cancel all Open Orders on a Symbol</h3>
 * <p>
 * <blockquote><pre>
 * client.cancelOpenOrders(symbol: string)
 * </pre></blockquote>
 * <p>
 * <h3>Query Order</h3>
 * <p>
 * <blockquote><pre>
 * client.queryOrder(symbol: string, options:any = {})
 * options:{ orderId, origClientOrderId}
 * /**
 *  *
 *  * Either orderId or origClientOrderId must be sent
 *  *
 *  * orderId:
 *  *      target orderId
 *  *
 *  * origClientOrderId:
 *  *      target origClientOrderId
 *  *
 *  *&#47;
 * </pre></blockquote>
 * <p>
 * <h3>Current Open Orders</h3>
 * <p>
 * <blockquote><pre>
 * client.openOrders(symbol: string)
 * </pre></blockquote>
 * <p>
 * <h3>All Orders</h3>
 * <p>
 * <blockquote><pre>
 * client.allOrders(symbol: string, options: any = { limit: 500 })
 * options:{ orderId, startTime, endTime, limit}
 * 
 * /**
 *  *
 *  * orderId:
 *  *      target orderId
 *  *
 *  * startTime:
 *  *      start at
 *  *
 *  * endTime:
 *  *      end at
 *  *
 *  * limit :
 *  *      Number of returned data
 *  *      Default 500;
 *  *      max 1000;
 *  *
 *  *&#47;
 * </pre></blockquote>
 * <p>
 * <h3>Account Information</h3>
 * <p>
 * <blockquote><pre>
 * client.accountInfo()
 * </pre></blockquote>
 * <p>
 * <h3>Account Trade List</h3>
 * <p>
 * <blockquote><pre>
 * client.accountTradeList(symbol: string, options:any = { limit: 500 })
 * options:{ orderId, startTime, endTime, fromId, limit}
 * 
 * /**
 *  *
 *  * orderId:
 *  *      target orderId
 *  *
 *  * startTime:
 *  *      start at
 *  *
 *  * endTime:
 *  *      end at
 *  *
 *  * fromId:
 *  *      TradeId to fetch from. Default gets most recent trades
 *  *
 *  * limit :
 *  *      Number of returned data
 *  *      Default 500;
 *  *      max 1000;
 *  *
 *  *&#47;
 * </pre></blockquote>
 */
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
package Mexc.Sdk;
